 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: OAG_AltServers.sas                           |
   |   TITLE: Annotate points on a background map with no  |
   |          polygons.  Create the background view with   |
   |          the annotate points.  Use different          |
   |          Background servers.                          |   
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/

/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";

/*location of the programs */
libname OAG 'C:\SGF2013\AFpgm';

/* reset the macro variables */
%include "c:\SGF2013\AFpgm\OAG_reset.sas";

/* Security incidents */
data incident;
   input lat long incident $21-40 date $;
cards;
35.824302 -78.75533  FLAT TIRE           01Jun12
35.82399  -78.757253 Parking Violation   05Jun12
35.82432  -78.758583 Parking Violation   14Jun12
35.824303 -78.763497 Accident            18Jun12
35.827539 -78.761673 Car theft           22Jun12
35.823102 -78.752403 Break/enter Car     25Jun12
35.817674 -78.750107 Parking Violation   01Aug12
35.81743  -78.749185 Parking Violation   02Aug12
;
run;

/* Add x and y, plus make a tool tip variable */
data sec_inc; set incident; 
    x=long; y=lat; 
    details=trim(left(date))|| ": " || trim(left(incident)); 
run;



/* Create annotate data set of dots at locations */
%make_dots(annodots, sec_inc,'RED');

/*************************************************************
 * Use the _inannods to created the background map that 
 * contains the area needed for the points. A bounding box
 * map is created. _autoproject is on, so project the data set 
 * into _outmapds.  _outannods contains the projected _inannods
 * data.  _outannoOSMds will contain the output
 * annotate data with the background image tiles.  The 
 * background images are stored in _imageloc.  The graph area
 * is defined by _xpixels and _ypixels.  The tiles come from
 * the default SAS _tileserv (tile server).
 *************************************************************/
%let _backgroundonly='YES'; 
%let _inannods=annodots;
%let _outannods=mannodots;
%let _outmapds=mmap;
%let _outannoOSMds=work.mannoosm;
%let _imageloc='c:\OSM\'; /*must have final slash*/
%let _xpixels=800;
%let _ypixels=600;
%let _autoproject='Y';


%let _tileserv="SAS";
/* Some example alternate map servers.                */
/* Check legal restrictions on each site before using */
/* Note that performance may be slow on some servers  */ 
*%let _tileserv=otile3.mqcdn.com/tiles/1.0.0/osm;
*%let _tileserv=c.tile.openstreetmap.org;
%let _tileserv=otile1.mqcdn.com/tiles/1.0.0/sat; /* Sat image - the new location*/
%let _tileserv=tile.stamen.com/terrain-background; /*terrain */


/* for non-sas _tileserv, set the proper _copyright message */
%let _copyright="Data, imagery and map information provided by MapQuest, Open Street Map  and contributors, CC-BY-SA .";
%let _copyright="Map tiles by Stamen Design, under CC-BY-3.0. Data by OpenStreetMap, under CC-BY-SA.";

goptions reset;
/* Set xpixels, ypixels to the size to be used */
goptions xpixels=&_xpixels ypixels=&_ypixels;

/* Generate background image */
proc display cat=OAG.osmmapanno.osm_anno_gen.scl; run;



/*Combine the annotate data sets - The background and the dots*/
data bothanno;
   set &_outannoOSMds mannodots;
run;


/************************************************************
 * Create an HTML file showing the map and points.          
 ************************************************************/
GOPTIONS DEVICE=png;
ODS LISTING CLOSE;
ODS HTML path=odsout body="AltServer_png..html";
pattern; /*reset pattern statements */

/*Transparent color*/
pattern v=me c=A00000000 r=100;  /*will not work before 9.3*/
  
/*Draw _outmapds map dataset that was projected to mercator, */
/*use the _annooutOSMds created that has the background map  */
/*images and color the choropleth with the crime data        */
proc gmap map=&_outmapds anno=bothanno data=&_outmapds all;  
     id id;  
     choro id /nolegend name="AltServer";
run;
quit;
ODS HTML CLOSE;
ODS LISTING;

/***** An alternate macro to do above gmap code ****
%draw_map(&_outmapds,&_outmapds, bothanno,id,id,AltServer,png,"N");
******/
pattern;