 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: OAG_AnnoMap.sas                              |
   |   TITLE: Annotate points on a background map with no  |
   |          polygons.  Create the background view with   |
   |          the annotate points.  GfK maps               |   
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/

/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";

/*location of the programs */
libname OAG 'C:\SGF2013\AFpgm';

/* reset the macro variables */
%include "c:\SGF2013\AFpgm\OAG_reset.sas";

/* Cities you want to show on the map */
data mycities;
   input state $ 1-2 city $ 4-20;
cards;
NC RALEIGH
NY NEW YORK
TX DALLAS
FL MIAMI
;
run;

/* Get the lat/long location of each city */
Proc geocode 
   method=city
   data=mycities
   out=gmycities;
run;

/* Set x and y for later use */
data gmycities; 
    set gmycities; 
    x=long; y=lat; 
run;

/* Create annotate data set of dots at locations */
%make_dots(annocity,gmycities,'RED');

/* Convert to mercator projection*/
%to_mercator(mannocity, annocity, 0);

/* Make a map of the 48 states */
/* Subset map for Florida counties only */
data mymap; set mapsgfk.us_states (where=(statecode ne 'AK' and  
                                  statecode ne 'HI'));
    /* lat, long are unprojected in MAPSGFK data */
    /* Save as y, x to make easier to use        */   
    x=long; y=lat; 
run;

/*************************************************************
 * Use the _inmapds to created the background map that 
 * contains the 48 states. A bounding box
 * map is created. _autoproject is on, so project the data set 
 * into _outmapds.  _outannods contains the projected _inannods
 * data.  _outannoOSMds will contain the output
 * annotate data with the background image tiles.  The 
 * background images are stored in _imageloc.  The graph area
 * is defined by _xpixels and _ypixels.  The tiles come from
 * the default SAS _tileserv (tile server).
 *************************************************************/
%let _backgroundonly='YES'; 
%let _inmapds=mymap;
%let _outmapds=mmap;
%let _outannoOSMds=work.mannoosm;
%let _imageloc='c:\OSM\'; /*must have final slash*/
%let _xpixels=800;
%let _ypixels=600;
%let _autoproject='Y';

goptions reset;
/* Set xpixels, ypixels to the size to be used */
goptions xpixels=&_xpixels ypixels=&_ypixels;

/* Generate background image */
proc display cat=OAG.osmmapanno.osm_anno_gen.scl; run;

*goptions xpixels=&_bestxpixel ypixels=&_bestypixel;

/*Combine the annotate data sets - The background and the dots*/
data bothanno;
   set &_outannoOSMds mannocity;
run;


/************************************************************
 * Create an HTML file showing the map and points.          
 ************************************************************/
GOPTIONS DEVICE=png;
ODS LISTING CLOSE;
ODS HTML path=odsout body="AnnoMap_png..html";
pattern; /*reset pattern statements */

/*Transparent color*/
pattern v=me c=A00000000 r=100;  /*will not work before 9.3*/
  
/*Draw _outmapds map dataset that was projected to mercator, */
/*use the _annooutOSMds created that has the background map  */
/*images and color the choropleth with the crime data        */
proc gmap map=&_outmapds anno=bothanno data=&_outmapds all;  
     id id;  
     choro id /nolegend name="AnnoMap";
run;
quit;
ODS HTML CLOSE;
ODS LISTING;

/***** An alternate macro to do above gmap code ****
%draw_map(&_outmapds,&_outmapds, bothanno,id,id,AnnoMapAD,png,"N");
******/
