 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: OAG_ChoroMap.sas                             |
   |   TITLE: Draw Choropleth Map of crime data per        |
   |          county in Florida.  MAPS data.               |    
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/

/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";

/*location of the programs */
libname OAG 'C:\SGF2013\AFpgm';

/* reset the macro variables */
%include "c:\SGF2013\AFpgm\OAG_reset.sas";

/*location of crime data per county for US*/
filename crimedat 'c:\SGF2013\AFpgm\crime2.dat';

/* Subset map for Florida counties only */
/* in MAPS data sets, x and y are unprojected Radians */
data rmymap; set maps.counties (where=(state=(stfips('FL'))));  
run;

/* change data from radians to degrees */
%to_degrees(mymap,rmymap);

/* Process response data - crime data */
data crimeFL;
    infile crimedat;
    input countynm $1-13 arrests county;
run;

/*************************************************************
 * Use the _inmapds to created the background map that is just
 * Florida.  _autoproject is on, so project the map data set 
 * into _outmapds.  _outannoOSMds will contain the output
 * annotate data with the background image tiles.  The 
 * background images are stored in _imageloc.  The graph area
 * is defined by _xpixels and _ypixels.  The tiles come from
 * the default SAS _tileserv (tile server).
 *************************************************************/
%let _inmapds=mymap;
%let _outmapds=work.mmymap; 
%let _outannoOSMds=work.mannoosm;
%let _imageloc='c:\OSM\'; /*must have final slash*/
%let _xpixels=800;
%let _ypixels=600;
%let _autoproject='Y';

goptions reset;
/* Set xpixels, ypixels to the size to be used */
goptions xpixels=&_xpixels ypixels=&_ypixels;

/* Generate background image */
proc display cat=OAG.osmmapanno.osm_anno_gen.scl; run;


*goptions border;

/************************************************************
 * Create an HTML file showing the map and points.          
 ************************************************************/
GOPTIONS DEVICE=png;
ODS LISTING CLOSE;
ODS HTML path=odsout body="ChoroFl_png.html";
pattern; /*reset pattern statements */

/* Set transparent colors - works in 9.3 and 9.4 */
pattern1  v=solid repeat=1 c=A00ff00aa;
pattern2  v=solid repeat=1 c=A0000feaa;
pattern3  v=solid repeat=1 c=A3661feaa;
pattern4  v=solid repeat=1 c=A38acffaa;
pattern5  v=solid repeat=1 c=A00ffffaa;
pattern6  v=solid repeat=1 c=A91ffb4aa;
pattern7  v=solid repeat=1 c=Ad2fe69aa;
pattern8  v=solid repeat=1 c=Affff00aa;
pattern9  v=solid repeat=1 c=Affb700aa;
pattern10 v=solid repeat=1 c=Aff6f00aa;
pattern11 v=solid repeat=1 c=Afe0000aa;
  
/*Draw _outmapds map dataset that was projected to mercator, */
/*use the _annooutOSMds created that has the background map  */
/*images and color the choropleth with the crime data        */
proc gmap map=&_outmapds anno=&_outannoOSMds data=crimefl all;  
     id county;  
     choro arrests /nolegend name="ChoroFl";
run;
quit;
ODS HTML CLOSE;
ODS LISTING;

/***** An alternate macro to do above gmap code ****
%draw_map(&_outmapds,crimefl,&_outannoOSMds,county,arrests,ChoroFL,png,"C");
******/
pattern;