 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: OAG_EmptyMapGfK.sas                          |
   |   TITLE: Draw Empty outline Map of Florida counties   |   
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/

/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";

/*location of the programs */
libname OAG 'C:\SGF2013\AFpgm';

/* reset the macro variables */
%include "c:\SGF2013\AFpgm\OAG_reset.sas";

/* Subset map for Florida counties only */
data mymap; set mapsgfk.us_counties (where=(statecode='FL')); 
    /* lat, long are unprojected in MAPSGFK data */
    /* Save as y, x to make easier to use        */   
    x=long; y=lat; 
run;


/*************************************************************
 * Use the _inmapds to created the background map that is just
 * Florida.  _autoproject is on, so project the map data set 
 * into _outmapds.  _outannoOSMds will contain the output
 * annotate data with the background image tiles.  The 
 * background images are stored in _imageloc.  The graph area
 * is defined by _xpixels and _ypixels.  The tiles come from
 * the default SAS _tileserv (tile server).
 *************************************************************/
%let _inmapds=mymap;
%let _outmapds=work.mmymap; 
%let _outannoOSMds=work.mannoosm;
%let _imageloc='c:\OSM\'; /*must have final slash*/
%let _xpixels=800;
%let _ypixels=600;
%let _tileserv=""; /* SAS tile server */
%let _autoproject='Y';

goptions reset;
/* Set xpixels, ypixels to the size to be used */
goptions xpixels=&_xpixels ypixels=&_ypixels;

/* Generate background image */
proc display cat=OAG.osmmapanno.osm_anno_gen.scl; run;


*goptions border;

/************************************************************
 * Create an HTML file showing the map and points.          
 ************************************************************/
GOPTIONS DEVICE=png;
ODS LISTING CLOSE;
ODS HTML path=odsout body="EmptyFlGfK_png..html";
pattern; /*reset pattern statements */


/*Transparent color*/
pattern v=me c=A00000000 r=100;  /*will not work before 9.3*/
  
/*Draw _outmapds map dataset that was projected to mercator, */
/*use the _annooutOSMds created that has the background map  */
/*images and color the choropleth with the crime data        */
proc gmap map=&_outmapds anno=&_outannoOSMds data=&_outmapds all;  
     id county;  
     choro county /nolegend name="EmptyFlGfK";
run;
quit;
ODS HTML CLOSE;
ODS LISTING;

/***** An alternate macro to do above gmap code ****
%draw_map(&_outmapds,&_outmapds,&_outannoOSMds,county,county,EmptyFLGfK,png,"N");
******/
pattern;