 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: MA_PointMap93.sas                            |
   |   TITLE: Draw dots on map for locations.  Drawn as    |
   |          map instead of annotate.  9.3 syntax.        |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/
/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";

/* Points for events on campus */
data myspots;
   input lat long incident $21-40 date $;
cards;
35.824302 -78.75533  FLAT TIRE           01Jun12
35.82399  -78.757253 Parking Violation   05Jun12
35.82432  -78.758583 Parking Violation   14Jun12
35.824303 -78.763497 Accident            18Jun12
35.827539 -78.761673 Car theft           22Jun12
35.823102 -78.752403 Break/enter Car     25Jun12
35.817674 -78.750107 Parking Violation   01Aug12
35.81743  -78.749185 Parking Violation   02Aug12
;
run;

/* add some details */
data dmyspots; 
   set myspots; 
   x=long; y=lat; 
   details=trim(left(date))|| ": " || trim(left(incident)); 
run;

/* Instead of annotate, draw map circles for each location*/
/* To do this, convert the degrees to radians as needed for */
/* the making the circles, then convert them back to degrees*/
%to_radians(rspots, dmyspots);
%make_circle(rmymap,rspots,x,y,.015,'red');
%to_degrees(mymap,rmymap);

/* Convert data to mercator */
%to_mercator(proj_map, mymap,  0);

goptions ypixels=600 xpixels=800;

pattern v=me c=cxff0000 r=100;
%let dev=JAVA;
%let name=PointMap93;

GOPTIONS CBACK=white;
GOPTIONS DEVICE=&dev;
ODS LISTING CLOSE;
ODS HTML path=odsout body="&name._&dev..html"
         parameters=("OSMSTYLE"="SASMAPNIK");
    ;
proc gmap map=proj_map data=proj_map ;
   id id;
  choro id / nolegend ;
run;
quit;
ods html close;
pattern;
